/*
 * @(#)src/classes/sov/java/io/DeleteOnExitHook.java, io, asdev, 20070425 1.1
 * ===========================================================================
 * IBM Confidential
 * OCO Source Materials
 *
 * IBM SDK, Java(tm) 2 Technology Edition, v5.0
 * (C) Copyright IBM Corp. 1998, 2005.
 *
 * The source code for this program is not published or otherwise divested of
 * its trade secrets, irrespective of what has been deposited with the U.S.
 * Copyright office.
 * ===========================================================================
 */

/*
 * ===========================================================================
 (C) Copyright Sun Microsystems Inc, 1992, 2004. All rights reserved.
 * ===========================================================================
 */

package java.io;

import java.util.*;
import java.io.File;

/**
 * This class holds a set of filenames to be deleted on VM exit through a shutdown hook.
 * A set is used both to prevent double-insertion of the same file as well as offer 
 * quick removal.
 */

class DeleteOnExitHook {
    private static DeleteOnExitHook instance = null;

    private static Collection<String> files = new HashSet<String>();

    static DeleteOnExitHook hook() {
        if (instance == null)
            instance = new DeleteOnExitHook();

        return instance;
    }

    private void DeleteOnExitHook() {}

    static void add(String file) {
        synchronized(files) {
            if(files == null)
                throw new IllegalStateException("Shutdown in progress");

            files.add(file);
        }
    }

    void run() {
        Collection<String> theFiles;

        synchronized (files) {
            theFiles = files;
            files = null;
        }

        ArrayList<String> toBeDeleted = new ArrayList<String>(theFiles);
        for (String filename : toBeDeleted) {
            (new File(filename)).delete();
        }
    }
}

